@@ -5,7 +5,7 @@ use bevy_prototype_lyon::entity::ShapeBundle;
 use bevy_prototype_lyon::prelude::*;
 use bevy_prototype_lyon::shapes::RectangleOrigin;
 
-use heron_core::CollisionShape;
+use heron_core::{CollisionShape, RigidBody, SensorShape};
 use heron_rapier::convert::IntoBevy;
 use heron_rapier::rapier2d::geometry::{ColliderHandle, ColliderSet, Shape};
 
@@ -23,12 +23,19 @@ fn create_debug_sprites(
     colliders: Res<'_, ColliderSet>,
     query: Query<
         '_,
-        (Entity, &CollisionShape, &ColliderHandle, &GlobalTransform),
+        (
+            Entity,
+            &CollisionShape,
+            &ColliderHandle,
+            &GlobalTransform,
+            Option<&RigidBody>,
+            Option<&SensorShape>,
+        ),
         Without<HasDebug>,
     >,
     debug_color: Res<'_, DebugColor>,
 ) {
-    for (entity, body, handle, transform) in query.iter() {
+    for (entity, body, handle, transform, rigid_body_option, sensor_option) in query.iter() {
         if let Some(collider) = colliders.get(*handle) {
             commands
                 .entity(entity)
@@ -37,7 +44,8 @@ fn create_debug_sprites(
                         .spawn_bundle(create_shape(
                             body,
                             collider.shape(),
-                            (*debug_color).into(),
+                            debug_color
+                                .for_collider_type(rigid_body_option, sensor_option.is_some()),
                             *transform,
                         ))
                         .insert(IsDebug(entity));
@@ -54,11 +62,18 @@ fn replace_debug_sprite(
     debug_color: Res<'_, DebugColor>,
     query: Query<
         '_,
-        (Entity, &CollisionShape, &ColliderHandle, &GlobalTransform),
+        (
+            Entity,
+            &CollisionShape,
+            &ColliderHandle,
+            &GlobalTransform,
+            Option<&RigidBody>,
+            Option<&SensorShape>,
+        ),
         (With<HasDebug>, Changed<CollisionShape>),
     >,
 ) {
-    for (parent_entity, body, handle, transform) in query.iter() {
+    for (parent_entity, body, handle, transform, rigid_body_option, sensor_option) in query.iter() {
         if let (Some(debug_entity), Some(collider)) =
             (map.remove(&parent_entity), colliders.get(*handle))
         {
@@ -68,7 +83,7 @@ fn replace_debug_sprite(
                     .spawn_bundle(create_shape(
                         body,
                         collider.shape(),
-                        (*debug_color).into(),
+                        debug_color.for_collider_type(rigid_body_option, sensor_option.is_some()),
                         *transform,
                     ))
                     .insert(IsDebug(parent_entity));
