@@ -7,15 +7,29 @@
 use bevy::prelude::*;
 use fnv::FnvHashMap;
 
+#[cfg(any(feature = "2d", feature = "3d"))]
+use heron_core::RigidBody;
+
 #[cfg(all(feature = "2d", not(feature = "3d")))]
 mod dim2;
 
+#[cfg(feature = "3d")]
+mod dim3;
+
+#[cfg(feature = "3d")]
+mod shape3d_wireframe;
+
 /// Plugin that enables rendering of collision shapes
-#[derive(Debug, Copy, Clone)]
-pub struct DebugPlugin(Color);
+#[derive(Debug, Copy, Clone, Default)]
+pub struct DebugPlugin(DebugColor);
 
 #[derive(Debug, Copy, Clone)]
-struct DebugColor(Color);
+struct DebugColor {
+    sensor: Color,
+    static_body: Color,
+    dynamic_body: Color,
+    kinematic_body: Color,
+}
 
 type DebugEntityMap = FnvHashMap<Entity, Entity>;
 
@@ -28,42 +42,61 @@ struct IsDebug(Entity);
 #[allow(unused)]
 struct Indexed;
 
-impl From<Color> for DebugPlugin {
-    fn from(color: Color) -> Self {
-        Self(color)
-    }
-}
-
-impl Default for DebugPlugin {
-    fn default() -> Self {
-        let mut color = bevy::render::color::Color::BLUE;
-        color.set_a(0.4);
-        Self(color)
-    }
-}
-
 impl Plugin for DebugPlugin {
     fn build(&self, app: &mut AppBuilder) {
+        #[cfg(feature = "3d")]
+        app.add_plugin(bevy_prototype_debug_lines::DebugLinesPlugin)
+            .add_system_set_to_stage(CoreStage::PostUpdate, dim3::systems());
+
         #[cfg(all(feature = "2d", not(feature = "3d")))]
         app.add_plugin(bevy_prototype_lyon::plugin::ShapePlugin)
             .add_system_set_to_stage(CoreStage::PostUpdate, dim2::systems());
 
-        app.insert_resource(DebugColor(self.0))
+        app.insert_resource(self.0)
             .init_resource::<DebugEntityMap>()
             .add_system_to_stage(CoreStage::Last, track_debug_entities.system())
             .add_system_to_stage(CoreStage::Last, scale_debug_entities.system());
     }
 }
 
-impl From<Color> for DebugColor {
-    fn from(color: Color) -> Self {
-        Self(color)
+impl DebugColor {
+    #[cfg(any(feature = "2d", feature = "3d"))]
+    fn for_collider_type(
+        &self,
+        rigid_body_option: Option<&RigidBody>,
+        is_sensor_shape: bool,
+    ) -> Color {
+        if is_sensor_shape {
+            self.sensor
+        } else {
+            use RigidBody::{
+                KinematicPositionBased as PositionBased, KinematicVelocityBased as VelocityBased,
+            };
+            match rigid_body_option {
+                Some(RigidBody::Sensor) => self.sensor,
+                Some(RigidBody::Static) => self.static_body,
+                Some(RigidBody::Dynamic) | None => self.dynamic_body,
+                Some(PositionBased | VelocityBased) => self.kinematic_body,
+            }
+        }
     }
 }
 
-impl From<DebugColor> for Color {
-    fn from(DebugColor(color): DebugColor) -> Self {
-        color
+// 3d debug uses wireframes, it's easier to read with more opaque colors
+const DEFAULT_DEBUG_ALPHA: f32 = if cfg!(all(feature = "2d", not(feature = "3d"))) {
+    0.4
+} else {
+    0.8
+};
+
+impl Default for DebugColor {
+    fn default() -> Self {
+        Self {
+            sensor: Color::rgba(0.0, 0.63, 0.0, DEFAULT_DEBUG_ALPHA),
+            static_body: Color::rgba(0.64, 0.0, 0.16, DEFAULT_DEBUG_ALPHA),
+            dynamic_body: Color::rgba(0.0, 0.18, 0.54, DEFAULT_DEBUG_ALPHA),
+            kinematic_body: Color::rgba(0.21, 0.07, 0.7, DEFAULT_DEBUG_ALPHA),
+        }
     }
 }
 
@@ -89,7 +122,7 @@ fn scale_debug_entities(
         })
         .for_each(|(local, mut global)| {
             if let Some(mut local) = local {
-                local.scale *= global.scale.recip()
+                local.scale *= global.scale.recip();
             }
             global.scale.x = 1.0;
             global.scale.y = 1.0;
